@@ -1,4 +1,4 @@
-# $Id: xively.py 1164 2014-12-06 06:14:48Z mwall $
+# $Id: xively.py 1383 2015-10-31 15:59:53Z mwall $
 # Copyright 2013 Matthew Wall
 """
 Upload data to Xively (aka COSM, aka Pachube)
@@ -32,7 +32,7 @@ except Exception, e:
     except Exception, e:
         import json
 
-VERSION = "0.3"
+VERSION = "0.7"
 
 if weewx.__version__ < "3":
     raise weewx.UnsupportedFeature("weewx 3 is required, found %s" %
@@ -133,30 +133,15 @@ class Xively(weewx.restx.StdRESTbase):
         # for backward compatibility: 'station' is now 'prefix'
         _compat(site_dict, 'station', 'prefix')
 
-        errs = []
-        try:
-            if site_dict.has_key('append_units_label'):
-                site_dict['append_units_label'] = to_bool(
-                    site_dict['append_units_label'])
-        except ValueError, e:
-            errs.append("bad value for append_units_label: %s" % e)
-
-        if (site_dict.has_key('obs_to_upload') and
-            site_dict['obs_to_upload'].lower() not in ['all', 'none']):
-            errs.append("bad value for obs_to_upload")
+        site_dict.setdefault('append_units_label', True)
+        site_dict.setdefault('augment_record', True)
+        site_dict.setdefault('obs_to_upload', 'all')
+        site_dict['append_units_label'] = to_bool(site_dict.get('append_units_label'))
+        site_dict['augment_record'] = to_bool(site_dict.get('augment_record'))
 
         usn = site_dict.get('unit_system', None)
         if usn is not None:
-            if usn in weewx.units.unit_constants:
-                site_dict['unit_system'] = weewx.units.unit_constants[usn]
-            else:
-                errs.append("unknown unit_system %s" % usn)
-
-        if errs:
-            for msg in errs:
-                logerr(msg)
-            logerr("Data will not be uploaded")
-            return
+            site_dict['unit_system'] = weewx.units.unit_constants[usn]
 
         if config_dict['StdRESTful']['Xively'].has_key('channels'):
             site_dict['channels'] = dict(config_dict['StdRESTful']['Xively']['channels'])
@@ -181,7 +166,7 @@ class XivelyThread(weewx.restx.RESTThread):
     _SERVER_URL = 'http://api.xively.com/v2/feeds'
 
     def __init__(self, queue, feed, token, manager_dict,
-                 prefix=None, unit_system=None,
+                 prefix=None, unit_system=None, augment_record=True,
                  channels={}, obs_to_upload='all', append_units_label=True,
                  server_url=_SERVER_URL, skip_upload=False,
                  post_interval=None, max_backlog=sys.maxint, stale=None,
@@ -201,19 +186,21 @@ class XivelyThread(weewx.restx.RESTThread):
         self.feed = feed
         self.token = token
         self.prefix = prefix
-        self.upload_all = False if obs_to_upload.lower() == 'none' else True
+        self.upload_all = True if obs_to_upload.lower() == 'all' else False
         self.append_units_label = append_units_label
         self.channels = channels
         self.server_url = server_url
         self.skip_upload = to_bool(skip_upload)
         self.unit_system = unit_system
+        self.augment_record = augment_record
         self.templates = dict()
 
     def process_record(self, record, dbm):
-        r = self.get_record(record, dbm)
+        if self.augment_record:
+            record = self.get_record(record, dbm)
         if self.unit_system is not None:
-            r = weewx.units.to_std_system(r, self.unit_system)
-        data = self.get_data(r)
+            record = weewx.units.to_std_system(record, self.unit_system)
+        data = self.get_data(record)
         if self.skip_upload:
             loginf("skipping upload")
             return
