@@ -1,4 +1,4 @@
-# $Id: install.py 893 2014-03-13 04:24:14Z mwall $
+# $Id: install.py 1383 2015-10-31 15:59:53Z mwall $
 # installer for Xively
 # Copyright 2014 Matthew Wall
 
@@ -10,7 +10,7 @@ def loader():
 class XivelyInstaller(ExtensionInstaller):
     def __init__(self):
         super(XivelyInstaller, self).__init__(
-            version="0.2",
+            version="0.7",
             name='xively',
             description='Upload weather data to Xively.',
             author="Matthew Wall",
@@ -20,7 +20,6 @@ class XivelyInstaller(ExtensionInstaller):
                 'StdRESTful': {
                     'Xively': {
                         'token': 'INSERT_TOKEN_HERE',
-                        'feed': 'INSERT_FEED_HERE',
-                        'station_name': 'INSERT_STATION_NAME_HERE'}}},
+                        'feed': 'INSERT_FEED_HERE'}}},
             files=[('bin/user', ['bin/user/xively.py'])]
             )
